@@ -13,8 +13,9 @@ Another resource to understanding three.js decisions is the Udacity course on
 """
 
 from ipywidgets import Widget, DOMWidget, widget_serialization, Color
-from traitlets import (Unicode, Int, CInt, Instance, Enum, List, Dict, Float,
+from traitlets import (Unicode, CInt, Instance, Enum, List, Dict, Float,
                        CFloat, Bool)
+from ._package import npm_pkg_name
 from math import pi, sqrt
 
 def vector3(trait_type=CFloat, default=None, **kwargs):
@@ -29,8 +30,8 @@ def vector2(trait_type=CFloat, default=None, **kwargs):
 
 
 class Texture(Widget):
-    _view_module = Unicode('jupyter-threejs').tag(sync=True)
-    _model_module = Unicode('jupyter-threejs').tag(sync=True)
+    _view_module = Unicode(npm_pkg_name).tag(sync=True)
+    _model_module = Unicode(npm_pkg_name).tag(sync=True)
     _view_name = Unicode('TextureView').tag(sync=True)
     _model_name = Unicode('TextureModel').tag(sync=True)
 
@@ -92,8 +93,8 @@ class Object3d(Widget):
     """
     If matrix is not None, it overrides the position, rotation, scale, and up variables.
     """
-    _view_module = Unicode('jupyter-threejs').tag(sync=True)
-    _model_module = Unicode('jupyter-threejs').tag(sync=True)
+    _view_module = Unicode(npm_pkg_name).tag(sync=True)
+    _model_module = Unicode(npm_pkg_name).tag(sync=True)
     _view_name = Unicode('Object3dView').tag(sync=True)
     _model_name = Unicode('Object3dModel').tag(sync=True)
 
@@ -205,8 +206,8 @@ class ScaledObject(Object3d):
 
 
 class Controls(Widget):
-    _view_module = Unicode('jupyter-threejs').tag(sync=True)
-    _model_module = Unicode('jupyter-threejs').tag(sync=True)
+    _view_module = Unicode(npm_pkg_name).tag(sync=True)
+    _model_module = Unicode(npm_pkg_name).tag(sync=True)
     _view_name = Unicode('ControlsView').tag(sync=True)
     _model_name = Unicode('ControlsModel').tag(sync=True)
 
@@ -257,8 +258,8 @@ class Picker(Controls):
 
 
 class Geometry(Widget):
-    _view_module = Unicode('jupyter-threejs').tag(sync=True)
-    _model_module = Unicode('jupyter-threejs').tag(sync=True)
+    _view_module = Unicode(npm_pkg_name).tag(sync=True)
+    _model_module = Unicode(npm_pkg_name).tag(sync=True)
     _view_name = Unicode('GeometryView').tag(sync=True)
     _model_name = Unicode('GeometryModel').tag(sync=True)
 
@@ -452,8 +453,8 @@ class ParametricGeometry(Geometry):
 
 
 class Material(Widget):
-    _view_module = Unicode('jupyter-threejs').tag(sync=True)
-    _model_module = Unicode('jupyter-threejs').tag(sync=True)
+    _view_module = Unicode(npm_pkg_name).tag(sync=True)
+    _model_module = Unicode(npm_pkg_name).tag(sync=True)
     _view_name = Unicode('MaterialView').tag(sync=True)
     _model_name = Unicode('MaterialModel').tag(sync=True)
 
@@ -742,8 +743,8 @@ class Scene(Object3d):
 
 
 class Effect(Widget):
-    _view_module = Unicode('jupyter-threejs').tag(sync=True)
-    _model_module = Unicode('jupyter-threejs').tag(sync=True)
+    _view_module = Unicode(npm_pkg_name).tag(sync=True)
+    _model_module = Unicode(npm_pkg_name).tag(sync=True)
 
 
 class AnaglyphEffect(Effect):
@@ -752,8 +753,8 @@ class AnaglyphEffect(Effect):
 
 
 class Renderer(DOMWidget):
-    _view_module = Unicode('jupyter-threejs').tag(sync=True)
-    _model_module = Unicode('jupyter-threejs').tag(sync=True)
+    _view_module = Unicode(npm_pkg_name).tag(sync=True)
+    _model_module = Unicode(npm_pkg_name).tag(sync=True)
     _view_name = Unicode('RendererView').tag(sync=True)
     _model_name = Unicode('RendererModel').tag(sync=True)
 
@@ -765,7 +766,7 @@ class Renderer(DOMWidget):
     controls = List(Instance(Controls)).tag(sync=True, **widget_serialization)
     effect = Instance(Effect, allow_none=True).tag(sync=True, **widget_serialization)
     background = Color('black', allow_none=True).tag(sync=True)
-    backgroud_opacity = Float(min=0.0, max=1.0).tag(sync=True)
+    background_opacity = Float(min=0.0, max=1.0).tag(sync=True)
 
 
 class Light(Object3d):
